/* $Id: gnome--.h,v 1.10 1998/12/09 01:49:33 hp Exp $ */
#ifndef GNOME_MINUS_MINUS_H
#define GNOME_MINUS_MINUS_H 1

#include <gtk--.h>

class Gnome_About;
class Gnome_App;
class Gnome_AppBar;
class Gnome_CanvasEllipse;
class Gnome_CanvasGroup;
class Gnome_CanvasItem;
class Gnome_CanvasRect;
class Gnome_CanvasWidget;
class Gnome_CanvasImage;
class Gnome_CanvasLine;
class Gnome_CanvasText;
class Gnome_Canvas;
class Gnome_ColorPicker;
class Gnome_Dialog;
class Gnome_IconList;
class Gnome_Main;
class Gnome_Pixmap;

#include <gnome--/about.h>
#include <gnome--/app.h>
#include <gnome--/appbar.h>
#include <gnome--/canvas-ellipse.h>
#include <gnome--/canvas-group.h>
#include <gnome--/canvas-item.h>
#include <gnome--/canvas-rect.h>
#include <gnome--/canvas-widget.h>
#include <gnome--/canvas-image.h>
#include <gnome--/canvas-line.h>
#include <gnome--/canvas-text.h>
#include <gnome--/canvas.h>
#include <gnome--/color-picker.h>
#include <gnome--/dialog.h>
#include <gnome--/functions.h>
#include <gnome--/icon-list.h>
#include <gnome--/main.h>
#include <gnome--/pixmap.h>

#endif /* GNOME_MINUS_MINUS_H */
